@@ -79,6 +79,8 @@ module Senna
   LOG_MESSAGE                   =      0x0004
   LOG_LOCATION                  =      0x0008
 
+  DEFAULT_PORT                  =      10041
+
   class Index
     attr_reader :handle
     attr_reader :key_size, :flags, :initial_n_segments, :encoding
@@ -774,6 +776,52 @@ module Senna
     end
   end
 
+  class Client
+    def Client::init()
+      Senna::sen_com_init
+    end
+    def Client::fin()
+      Senna::sen_com_fin
+    end
+
+    def Client::open(host='localhost', port=DEFAULT_PORT)
+      handle = Senna::sen_com_client_open(host, port)
+      return new(handle)
+    end
+
+    def Client.callback(handle)
+      proc { Senna::sen_com_client_close(handle) }
+    end
+
+    def initialize(handle)
+      @handle = handle
+      ObjectSpace.define_finalizer(self, Client.callback(@handle))
+    end
+
+    def send(message)
+      return Senna::sen_com_client_send(@handle, message, message.length, 0)
+    end
+
+    def recv()
+      return Senna::sen_com_client_recv(@handle)
+    end
+
+    def exec(message)
+      send(message)
+      res = []
+      loop {
+        r = recv
+        res << r[1]
+        break if r[2] == 0
+      }
+      res
+    end
+
+    def fd()
+      return Senna::sen_com_client_fd(@handle)
+    end
+  end
+
   def Senna::get_select_optarg(mode, similarity_threshold_max_interval=0, weight_vector=nil, &func)
     i = Senna::SelectOptarg.new
     i.mode = mode
@@ -828,4 +876,5 @@ module Senna
     msg = format(fmt, *args)
     sen_logger_put(level, '', 0, '', '%s', msg)
   end
+
 end
