@@ -53,7 +53,7 @@ struct _sen_inv_updspec {
   int32_t tf;
   struct _sen_inv_pos *pos;
   struct _sen_inv_pos *tail;
-  sen_store_vnode *vnodes;
+  sen_vgram_vnode *vnodes;
 };
 
 typedef struct _sen_inv_updspec sen_inv_updspec;
@@ -118,6 +118,8 @@ sen_rc sen_inv_cursor_next(sen_inv_cursor *c);
 sen_rc sen_inv_cursor_next_pos(sen_inv_cursor *c);
 sen_rc sen_inv_cursor_close(sen_inv_cursor *c);
 
+int sen_inv_check(sen_inv *inv);
+
 #ifdef __cplusplus
 }
 #endif
