@@ -4,12 +4,12 @@
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.
-  
+
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
-  
+
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -106,11 +106,11 @@ sen_io_create(const char *path, uint32_t header_size, uint32_t segment_size,
   for (b = pagesize; b < total_header_size; b += pagesize);
   bs = (b + segment_size - 1) / segment_size;
   max_nfiles = (unsigned int)(
-    ((uint64_t)segment_size * (max_segment + bs) + SEN_IO_FILE_SIZE - 1) 
+    ((uint64_t)segment_size * (max_segment + bs) + SEN_IO_FILE_SIZE - 1)
     / SEN_IO_FILE_SIZE);
   if (!(fis = SEN_MALLOC(sizeof(fileinfo) * max_nfiles))) { return NULL; }
   sen_fileinfo_init(fis, max_nfiles);
-  if (!sen_open(fis, path, O_RDWR|O_CREAT|O_TRUNC, SEN_IO_FILE_SIZE)) { 
+  if (!sen_open(fis, path, O_RDWR|O_CREAT|O_TRUNC, SEN_IO_FILE_SIZE)) {
     if ((header = SEN_MMAP(&fis->fmo, fis, 0, b))) {
       header->header_size = header_size;
       header->segment_size = segment_size;
@@ -180,7 +180,7 @@ sen_io_open(const char *path, sen_io_mode mode, uint32_t cache_size)
   for (b = pagesize; b < total_header_size; b += pagesize);
   bs = (b + segment_size - 1) / segment_size;
   max_nfiles = (unsigned int)(
-    ((uint64_t)segment_size * (max_segment + bs) + SEN_IO_FILE_SIZE - 1) 
+    ((uint64_t)segment_size * (max_segment + bs) + SEN_IO_FILE_SIZE - 1)
     / SEN_IO_FILE_SIZE);
   if (!(fis = SEN_MALLOC(sizeof(fileinfo) * max_nfiles))) { return NULL; }
   sen_fileinfo_init(fis, max_nfiles);
@@ -230,7 +230,7 @@ sen_io_close(sen_io *io)
   uint32_t max_segment = io->header->max_segment;
   uint32_t segment_size = io->header->segment_size;
   unsigned int max_nfiles = (unsigned int)(
-    ((uint64_t)segment_size * (max_segment + bs) + SEN_IO_FILE_SIZE - 1) 
+    ((uint64_t)segment_size * (max_segment + bs) + SEN_IO_FILE_SIZE - 1)
     / SEN_IO_FILE_SIZE);
   for (mi = io->maps, i = max_segment; i; mi++, i--) {
     if (mi->map) {
@@ -288,7 +288,7 @@ sen_io_size(sen_io *io, off_t *size)
   uint32_t max_segment = io->header->max_segment;
   uint32_t segment_size = io->header->segment_size;
   unsigned int max_nfiles = (unsigned int)(
-    ((uint64_t)segment_size * (max_segment + bs) + SEN_IO_FILE_SIZE - 1) 
+    ((uint64_t)segment_size * (max_segment + bs) + SEN_IO_FILE_SIZE - 1)
     / SEN_IO_FILE_SIZE);
   for (fno = 0; fno < max_nfiles; fno++) {
     gen_pathname(io->path, buffer, fno);
@@ -398,7 +398,7 @@ sen_io_win_map(sen_io *io, sen_io_win *iw, uint32_t segment,
     }
     iw->addr = p + offset;
     break;
-  case sen_io_wronly: 
+  case sen_io_wronly:
     if (!(p = SEN_MALLOC(size))) { return NULL; }
     memset(p, 0, size);
     iw->addr = p;
@@ -424,7 +424,7 @@ sen_io_win_mapv(sen_io_win **list, int nent)
   sen_io_win *iw;
   struct aiocb *iocbs[MAX_REQUEST];
   struct aiocb iocb[MAX_REQUEST];
-  CacheIOOper oper[MAX_REQUEST]; 
+  CacheIOOper oper[MAX_REQUEST];
   int count = 0;
 
   sen_io_win **clist = list;
@@ -435,7 +435,7 @@ retry:
     iw = list[i];
     if (sen_aio_enabled && iw->mode == sen_io_rdonly) {
         /* this block is same as sen_io_win_map() */
-        sen_io *io = iw->io;        
+        sen_io *io = iw->io;
         uint32_t segment = iw->segment, offset = iw->offset, size = iw->size;
         byte *p;
         off_t pos;
@@ -515,7 +515,7 @@ retry:
 
                 /* This is not cached  */
                 oper[count].cd = NULL;
-                iw->cached = -1; 
+                iw->cached = -1;
 
                 /* aio count up */
                 count++;
@@ -534,7 +534,7 @@ retry:
     }
   }
 
-  if (sen_aio_enabled) {      
+  if (sen_aio_enabled) {
       if (count > 0) {
           int c;
 
@@ -543,7 +543,6 @@ retry:
               perror ("lio_listio");
               return sen_other_error;
           }
-          
           for (c=0;c<count;c++) {
               /* cache data is now VALID */
               if (oper[c].cd) oper[c].cd->flag = CACHE_VALID;
@@ -558,7 +557,7 @@ retry:
           /* update list and nent for loop */
           list = clist; /* list of iw which use CACHE_READ CacheData */
           nent = cl;    /* number of iw */
-          cl = 0; 
+          cl = 0;
           count = 0;
           usleep(1);
           goto retry;
@@ -609,7 +608,7 @@ sen_io_win_unmap(sen_io_win *iw)
     }
     iw->addr = NULL;
     break;
-  case sen_io_wronly: 
+  case sen_io_wronly:
     {
       int fno = (iw->segment + io->base_seg) / segments_per_file;
       fileinfo *fi = &io->fis[fno];
@@ -669,7 +668,7 @@ sen_io_seg_map_(sen_io *io, uint32_t segno, sen_io_mapinfo *info)
   SEG_MAP(io, segno, info);
 }
 
-void * 
+void *
 sen_io_seg_ref(sen_io *io, uint32_t segno)
 {
   uint32_t retry, *pnref;
@@ -811,7 +810,7 @@ sen_mmap(HANDLE *fmo, fileinfo *fi, off_t offset, size_t length)
   if (res) {
     mmap_size += length;
   } else {
-    SEN_LOG(sen_log_alert, "MapViewOfFile failed #%d", GetLastError());
+    SEN_LOG(sen_log_alert, "MapViewOfFile failed #%d <%d>", GetLastError(), mmap_size);
   }
   /* MUTEX_UNLOCK(fi->mutex); */
   return res;
@@ -824,12 +823,16 @@ sen_munmap(HANDLE *fmo, void *start, size_t length)
   if (UnmapViewOfFile(start)) {
     mmap_size -= length;
   } else {
-    SEN_LOG(sen_log_alert, "munmap(%p,%d) failed <%d>", start, length, mmap_size);
+    SEN_LOG(sen_log_alert, "munmap(%p,%d) failed #%d <%d>", start, length, GetLastError(), mmap_size);
     r = -1;
   }
   if (*fmo) {
-    CloseHandle(*fmo);
+    if (!CloseHandle(*fmo)) {
+      SEN_LOG(sen_log_alert, "closehandle(%p,%d) failed #%d", start, length, GetLastError());
+    }
     *fmo = NULL;
+  } else {
+    SEN_LOG(sen_log_alert, "fmo not exists <%p,%d>", start, length);
   }
   return r;
 }
@@ -918,7 +921,7 @@ sen_mmap(fileinfo *fi, off_t offset, size_t length)
   if (res) {
     mmap_size += length;
   } else {
-    SEN_LOG(sen_log_alert, "MapViewOfFile failed #%d", GetLastError());
+    SEN_LOG(sen_log_alert, "MapViewOfFile failed #%d  <%d>", GetLastError(), mmap_size);
   }
   return res;
 }
@@ -1030,7 +1033,7 @@ sen_get_pagesize(void)
 inline static sen_rc
 sen_open(fileinfo *fi, const char *path, int flags, size_t maxsize)
 {
-  struct stat st;    
+  struct stat st;
   if ((fi->fd = open(path, flags, 0666)) == -1) {
     return sen_file_operation_error;
   }
@@ -1075,7 +1078,7 @@ sen_mmap(fileinfo *fi, off_t offset, size_t length)
   }
   res = mmap(NULL, length, PROT_READ|PROT_WRITE, MAP_SHARED, fi->fd, offset);
   if (MAP_FAILED == res) {
-    SEN_LOG(sen_log_alert, "mmap(%z,%d,%d)=%s <%z>", length, fi->fd, offset, strerror(errno), mmap_size);
+    SEN_LOG(sen_log_alert, "mmap(%zd,%d,%d)=%s <%zd>", length, fi->fd, offset, strerror(errno), mmap_size);
     return NULL;
   }
   mmap_size += length;
@@ -1094,7 +1097,7 @@ sen_munmap(void *start, size_t length)
   int res;
   res = munmap(start, length);
   if (res) {
-    SEN_LOG(sen_log_alert, "munmap(%p,%z) failed <%z>", start, length, mmap_size);
+    SEN_LOG(sen_log_alert, "munmap(%p,%zd) failed <%zd>", start, length, mmap_size);
   } else {
     mmap_size -= length;
   }
