@@ -217,7 +217,7 @@ sen_ngram_next(sen_lex *lex)
 #ifndef NO_MECAB
 
 static mecab_t *sole_mecab;
-sen_mutex sole_mecab_lock;
+static sen_mutex sole_mecab_lock;
 
 inline static sen_lex *
 sen_mecab_open(sen_sym *sym, sen_nstr *nstr, uint8_t flags)
